@@ -1,8 +1,11 @@
 import asyncio
 import io
+from abc import ABCMeta
 
-from tsutils.enums import Server
-from tsutils.errors import IndexNotLoaded
+from discord.ext.commands import CogMeta
+
+from .enums import Server
+from .errors import IndexNotLoaded
 
 
 class aobject(object):
@@ -22,6 +25,10 @@ class aobject(object):
     __init__ = __ainit__
 
 
+class CogABCMeta(ABCMeta, CogMeta):
+    """A metaclass that implements ABCMeta and CogMeta"""
+
+
 class CtxIO(io.IOBase):
     def __init__(self, ctx):
         self.ctx = ctx
